@@ -5,7 +5,7 @@
 import time
 import warnings
 
-from mock import Mock, patch
+from unittest.mock import Mock, patch
 
 import browserid
 from browserid.tests.support import (patched_supportdoc_fetching,
